<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>IsometricView</name>
    <message>
        <location filename="../IsometricView.js" line="+44"/>
        <source>&amp;Isometric View</source>
        <translation>&amp;Izometrický pohled</translation>
    </message>
</context>
</TS>
